# For customisation by distributions. Only one option should be enabled.
%def_with sisyphus
%def_without junior
%def_without compact
%def_without master

%define ver_major 2.16

# Rename packages for different distributions.
%if_with junior
%define distr junior
%endif
%if_with master
%define distr master
%endif
%if_with compact
%define distr compact
%endif
%if_with sisyphus
%define distr sisyphus
%endif

Name: gnome
Version: %ver_major.0
Release: alt0.6

Summary: GNOME 2 Desktop installers
License: GPL
Group: Graphical desktop/GNOME

BuildArch: noarch

# The following are required versions of those packages that
# do not have GNOME-bound versioning.
## Core components
%define scrollkeeper_ver 0.3.14
## Applications
%define evolution_ver 2.8.0
%define gucharmap_ver 1.8.0
## Default settings package
%define gnome_settings_ver 2.6.0
## Engines, themes
%define engines_ver 2.8.0
%define icon_theme_ver %ver_major
%define themes_ver %ver_major
%define gtk_theme_prefix gtk2-theme
%define wm_theme_prefix metacity-theme
%define gnome_theme_prefix gnome-theme

# Some definitions for different distributions
# FIXME: Except Sisyphus, distro-specific install-sets were not checked and
# are most likely obsolete (e.g. gtk-engines-metal is obsolete now). We
# should work out some new designs for distributions.
%if_with junior
%define default_gnome_theme		gtk2-themes-bluebubble
%define default_gnome_theme_name		bluebubble
%define default_wm_theme		metacity-theme-gorilla
%define default_wm_theme_name		AgingGorilla
%define more_gtk2_themes		gtk2-themes-water-luna
%define more_wm_themes			metacity-themes-metabox
%endif
%if_with master
%define default_gnome_theme		gtk2-theme-fishing-the-sky
%define default_gnome_theme_name		fishing-the-sky
%define default_wm_theme		metacity-theme-crux
%define default_wm_theme_name		Crux
%define more_gtk2_themes		gtk-engines-metal
%define more_wm_themes			metacity-themes-metabox
%endif
%if_with sisyphus
%define default_gnome_theme		%gnome_theme_prefix-clearlooks >= %ver_major
%define default_gnome_theme_name		Clearlooks
%define default_wm_theme		%wm_theme_prefix-clearlooks
%define default_wm_theme_name		Clearlooks
# TODO: Create a gtk2-themes-default virtual package;
# libgtk-engines-default has little sense to an end user.
%define more_gtk2_themes		libgtk-engine-thinice, libgtk-engines-default, libgtk-engine-crux
%define more_wm_themes			%wm_theme_prefix-metabox
%endif

# GNOME 2.16 uses GConf 2.14
BuildPreReq: libGConf-devel >= 2.14

%description
A set of virtual packages for GNOME Desktop version 2 installation.

%package %distr-minimal
Summary: GNOME 2 Desktop minimal installer
Group: Graphical desktop/GNOME
PreReq: GConf >= 2.14
PreReq: scrollkeeper

# GNOME Desktop Core
Requires: gnome-session >= %ver_major
Requires: gnome-desktop >= %ver_major
Requires: gnome-panel >= %ver_major
Requires: gnome-control-center >= %ver_major
Requires: metacity >= %ver_major
Requires: yelp >= %ver_major
Requires: gnome-menus >= %ver_major

# Panel applets
Requires: gnome-applets-drivemount >= %ver_major
Requires: gnome-applets-multiload >= %ver_major
Requires: gnome-applets-gswitchit >= %ver_major

# GNOME Utilities
Requires: gnome-search-tool >= %ver_major
Requires: gnome-system-monitor >= %ver_major
Requires: gucharmap >= %gucharmap_ver
Requires: bug-buddy >= %ver_major
Requires: gnome-volume-manager >= 2.15
# gnome-calculator is provided by gcalctool and galculator
Requires: gnome-calculator

# Applications
## Default file manager
Requires: nautilus >= %ver_major
## Default terminal emulator
Requires: gnome-terminal >= %ver_major
## Default archiving tool
Requires: file-roller >= %ver_major
## Default text editor
Requires: gedit >= %ver_major
## A web browser (epiphany or galeon - TODO: make them provide this virtual)
#Requires: web-browser

# Look & Feel
## Default settings
Requires: gnome-settings >= %gnome_settings_ver
## Screensaver
Requires: xscreensaver-gnome

## Default themes
Requires: gnome-icon-theme >= %icon_theme_ver
Requires: %default_gnome_theme
Requires: %default_wm_theme

## And, of course, the documentation
Requires: gnome-user-docs >= %ver_major

%description %distr-minimal
This virtual package installs GNOME Desktop with minimum components. It
installs only a few applets, necessary utilities and a minimal set of themes.
Doesn't install games and media programs.

## =========================================================================

%package %distr-default
Summary: GNOME 2 Desktop installer for optimal user's requirements
Group: Graphical desktop/GNOME
Requires: gnome-%distr-minimal = %version-%release

Requires: gdm >= %ver_major

## Default web-browser
Requires: epiphany >= %ver_major
## Default mailer
Requires: evolution >= %evolution_ver

## Extended options, aka navoroty :)
Requires: gnome-vfs-module-sftp
Requires: gnome-vfs-module-smb

## Applets
Requires: gnome-applets >= %ver_major
# More applets, still on their way to Sisyphus.
#Requires: gnome-applets-deskbar >= %ver_major
#Requires: fast-user-switch-applet >= %ver_major

# Utilities
Requires: gnome-utils >= %ver_major
Requires: gconf-editor >= %ver_major
Requires: gnome-power-manager >= %ver_major
# GNOME menu editor - not yet in Sisyphus, too
#Requires: alacarte

# Applications
## Plugins for gedit
Requires: gedit-plugins >= %ver_major
## Stock multimedia applications
Requires: gnome-media >= %ver_major
## Default music player
Requires: rhythmbox
## Default media player
Requires: totem
## Stock GNOME games
Requires: gnome-games >= %ver_major
## Default image viewer
Requires: eog >= %ver_major
## Default CD/DVD burning interface
Requires: nautilus-cd-burner >= %ver_major

# Look & Feel
## All default themes
Requires: metacity-themes-default >= %ver_major
Requires: gnome-themes-default >= %ver_major

%description %distr-default
This virtual package installs GNOME Desktop for an average user's
requirements. It installs components from gnome-%distr-minimal package, some
games, media programs such as mixer, audio and video players, additional
themes, and some other programs that comprise GNOME Desktop.

%package %distr-a11y
Summary: GNOME 2 Desktop accessibility applications
Group: Graphical desktop/GNOME
# A synonym
Provides: %distr-accessibility
Requires: gnome-%distr-minimal = %version-%release

Requires: gok gnopernicus gnome-mag dasher gnome-themes-accessibility

%description %distr-a11y
This virtual package installs GNOME Desktop accessibility applications. These include an Gok - on-screen keyboard, Gnopernicus - a screen reader, Dasher - an innovative graphical input tool, and Magnifier (the name says for itself).

%post %distr-minimal
# FIXME: Put this into some schema please.
%gconf2_set string /desktop/gnome/interface/gtk_theme %default_gnome_theme_name
%gconf2_set string /apps/metacity/general/theme	%default_wm_theme_name

%files %distr-minimal
%files %distr-default
%files %distr-a11y

%changelog
* Fri Jan 19 2007 Alexey Rusakov <ktirf@altlinux.org> 2.16.0-alt0.6
- added to -default GNOME VFS modules that are now in separate packages.

* Mon Oct 16 2006 Alexey Rusakov <ktirf@altlinux.ru> 2.16.0-alt0.5
- use (for Sisyphus part, for the moment) theme names that comply with the
  themes policy draft.

* Sun Sep 10 2006 Alexey Rusakov <ktirf@altlinux.ru> 2.16.0-alt0.1
- new version 2.16.0
- fixes concerned with engines/themes
- added some dependencies, some of them commented out while there no needed
  programs in Sisyphus.

* Sun Aug 13 2006 Alexey Rusakov <ktirf@altlinux.ru> 2.15.0-alt0.1
- finished spec overhauling
- GNOME 2.16 beta

* Tue Jul 18 2006 Alexey Rusakov <ktirf@altlinux.ru> 2.14.0-alt1
- spec overhauled
- introduced binding to a common major version (many separate *_ver macros have gone then)
- moved some packages (incl. gdm, evolution and epiphany) from minimal to
  default set.
- removed -full package, most of its requirements have gone to the default set.

* Thu Mar 03 2005 Yuri N. Sedunov <aris@altlinux.ru> 2.10.0-alt1
- updated for newest versions.
- removed nautilus2-media, gnome-applets-modemlights,
  gnome-applets-cdplayer
- eog replaced by gthumb.

* Mon Jul 05 2004 Yuri N. Sedunov <aris@altlinux.ru> 2.6.1-alt1
- full-sisyphus requires gnome-applets-gswitchit-plugins,
  gtk-engines-full (vyt@, close #4687)

* Thu Apr 08 2004 Yuri N. Sedunov <aris@altlinux.ru> 2.6.0-alt1
- 2.6.0

* Mon Feb 02 2004 Yuri N. Sedunov <aris@altlinux.ru> 2.5.0-alt1
- 2.5.0

* Tue Dec 30 2003 Yuri N. Sedunov <aris@altlinux.ru> 2.4.0-alt1.1
- buildreqs GConf2 (close #3422).

* Fri Dec 26 2003 Yuri N. Sedunov <aris@altlinux.ru> 2.4.0-alt1
- 2.4.0

* Sat Jun 28 2003 Yuri N. Sedunov <aris@altlinux.ru> 2.3.3-alt1
- doesn't require newest ugly terminal.

* Sun May 18 2003 Yuri N. Sedunov <aris@altlinux.ru> 2.3.2-alt1
- gnome2-utils-{calculator,character-map} replaced
  by gcalctool and gucharmap respectively.
- gnome2-games-freecell replaced by gnome2-games-sol

* Fri Feb 14 2003 Yuri N. Sedunov <aris@altlinux.ru> 2.2.0-alt2
- Requirements updated.
- gswitchit go back.

* Thu Feb  6 2003 Stanislav Ievlev <inger@altlinux.ru> 2.2.0-alt1.1
- removed requires gnome-applets-extra-gswitchit
  Yuri, please stop unmets, I cannot build distribution

* Fri Jan 10 2003 Yuri N. Sedunov <aris@altlinux.ru> 2.2.0-alt1
- Requirements updated.
- more themes for gnome-default.
- gnome-degault requires nautilus-media.
- gnome-full requires galculator.

* Wed Dec 18 2002 Yuri N. Sedunov <aris@altlinux.ru> 2.1.5-alt1
- Requirements updated.

* Mon Dec 09 2002 Yuri N. Sedunov <aris@altlinux.ru> 2.1.0-alt0.6
- gnome-minimal requires xscreensaver-gnome, gnome-settings

* Sat Nov 30 2002 Yuri N. Sedunov <aris@altlinux.ru> 2.1.0-alt0.5
- s/gnome-applets-gswitchit/gnome-applets-extra-gswitchit/
- Removed obsoleted nautilus components.

* Thu Nov 28 2002 Yuri N. Sedunov <aris@altlinux.ru> 2.1.0-alt0.4
- Requirements updated.
- gnome2-utils-archive-generator replaced by file-roller.
- gnome-applets-gkb replaced by gnome-applets-gswitchit.

* Fri Nov 01 2002 Yuri N. Sedunov <aris@altlinux.ru> 2.1.0-alt0.3
- Removed obsoleted nautilus2-music-view component.
- Requirements updated.

* Thu Oct 24 2002 Yuri N. Sedunov <aris@altlinux.ru> 2.1.0-alt0.2
- Updated dependencies.

* Thu Oct 10 2002 Yuri N. Sedunov <aris@altlinux.ru> 2.1.0-alt0.1
- First test release.
